## A package as a complement for statistic computation
 
### Usage
```python
from stat_complement import HotellingT2,JacobiSolve

X=np.array([[-3,15],[4,16],[5,11]])
mu=np.array([[4,14]])
HotellingT2(X,mu)

# x: initial point delta: stop criteria
JacobiSolve(A,b,x,delta)
```

You are welcome to put up some function about statistic computation and I will try best to add it


